from django.conf import settings

from api_base.core.data_provider import DataProvider as BaseDataProvider

from ..arc_reader.writer.signal_value_generator import SignalValueGenerator

import datetime


class DataProvider(BaseDataProvider):

    def load(self, context, signal):
        result = []

        dt_start = context["dt_start"].strftime("%Y-%m-%d %H:%M:%S")
        dt_end = context["dt_end"].strftime("%Y-%m-%d %H:%M:%S")

        if settings.ARCHIVES_CPYTHON_LIBRARY is True:
            try:
                import arc_reader
                print("Reading from archives via CPython...")
                signals = []
                signals.append(signal.id)

                result1 = arc_reader.read(
                    settings.ARCHIVES_ROOT_DIR,
                    dt_start,
                    dt_end,
                    signals
                )

                result = []
                for row in result1:
                    dt = datetime.datetime(*map(int, [
                        row[0],
                        row[1],
                        row[2],
                        row[3],
                        row[4],
                        row[5],
                        row[6],
                    ]))

                    result.append([
                        dt,
                        row[7],
                        row[8],
                        row[9],
                        row[10],
                        row[11],
                    ])
            except Exception as e:
                print(e)
                provider = SignalValueGenerator(settings.ARCHIVES_ROOT_DIR)
                result = provider.load(context, signal, (dt_start, dt_end))
        else:
            print("Reading from archives via Python...")
            provider = SignalValueGenerator(settings.ARCHIVES_ROOT_DIR)
            result = provider.load(context, signal, (dt_start, dt_end))

        return result

    def load_multi(self, context, signals):
        result = []

        signals = [signal.id for signal in signals]
        dt_start = context["dt_start"].strftime("%Y-%m-%d %H:%M:%S")
        dt_end = context["dt_end"].strftime("%Y-%m-%d %H:%M:%S")

        if settings.ARCHIVES_CPYTHON_LIBRARY is True:
            try:
                import arc_reader
                print("Reading from archives via CPython...")

                result1 = arc_reader.read(
                    settings.ARCHIVES_ROOT_DIR,
                    dt_start,
                    dt_end,
                    signals
                )

                result = []
                for row in result1:
                    dt = datetime.datetime(*map(int, [
                        row[0],
                        row[1],
                        row[2],
                        row[3],
                        row[4],
                        row[5],
                        row[6],
                    ]))

                    result.append([
                        dt,
                        row[7],
                        row[8],
                        row[9],
                        row[10],
                        row[11],
                    ])
            except Exception as e:
                print(e)
                provider = SignalValueGenerator(settings.ARCHIVES_ROOT_DIR)
                result = provider.load_multi(context, signals, (dt_start, dt_end))
        else:
            print("Reading from archives via Python...")
            provider = SignalValueGenerator(settings.ARCHIVES_ROOT_DIR)
            result = provider.load_multi(context, signals, (dt_start, dt_end))

        return result
